;; Generated package description from mode-line-maker.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "mode-line-maker" "0.2.1.0.20260722.0" "Mode-line helper tools" '((emacs "29.1")) :commit "7af5dbe8dcf24725b106b5776008a3aef490de2b" :maintainer '("Nicolas P. Rougier" . "Nicolas.Rougier@inria.fr") :keywords '("convenience" "mode-line" "header-line") :url "https://github.com/rougier/mode-line-maker")
